read_inputs

Function read_inputs 

pub fn read_inputs(paths: &[PathBuf]) -> Vec<(PathBuf, Vec<u8>)>
Read the contents of each path. Files that cannot be read are silently omitted (the cache will miss on the next run, triggering a re-execution).