pub enum DefinitionEntry {
List(Vec<Command>),
Single(Command),
}Expand description
A reusable command definition: a single command mapping or a list of commands.
Variants
List(Vec<Command>)
A list of commands that will be inlined when the anchor is used.
Single(Command)
A single command.