Hooks

Struct Hooks 

pub struct Hooks {
Show 28 fields pub applypatch_msg: Option<HookConfig>, pub pre_applypatch: Option<HookConfig>, pub post_applypatch: Option<HookConfig>, pub pre_commit: Option<HookConfig>, pub pre_merge_commit: Option<HookConfig>, pub prepare_commit_msg: Option<HookConfig>, pub commit_msg: Option<HookConfig>, pub post_commit: Option<HookConfig>, pub pre_rebase: Option<HookConfig>, pub post_checkout: Option<HookConfig>, pub post_merge: Option<HookConfig>, pub pre_push: Option<HookConfig>, pub pre_receive: Option<HookConfig>, pub update: Option<HookConfig>, pub proc_receive: Option<HookConfig>, pub post_receive: Option<HookConfig>, pub post_update: Option<HookConfig>, pub reference_transaction: Option<HookConfig>, pub push_to_checkout: Option<HookConfig>, pub pre_auto_gc: Option<HookConfig>, pub post_rewrite: Option<HookConfig>, pub sendemail_validate: Option<HookConfig>, pub fsmonitor_watchman: Option<HookConfig>, pub p4_changelist: Option<HookConfig>, pub p4_prepare_changelist: Option<HookConfig>, pub p4_post_changelist: Option<HookConfig>, pub p4_pre_submit: Option<HookConfig>, pub post_index_change: Option<HookConfig>,
}
All supported git hooks. Configure any hook by adding its name as a key.

Fields

applypatch_msg: Option<HookConfig>pre_applypatch: Option<HookConfig>post_applypatch: Option<HookConfig>pre_commit: Option<HookConfig>pre_merge_commit: Option<HookConfig>prepare_commit_msg: Option<HookConfig>commit_msg: Option<HookConfig>post_commit: Option<HookConfig>pre_rebase: Option<HookConfig>post_checkout: Option<HookConfig>post_merge: Option<HookConfig>pre_push: Option<HookConfig>pre_receive: Option<HookConfig>update: Option<HookConfig>proc_receive: Option<HookConfig>post_receive: Option<HookConfig>post_update: Option<HookConfig>reference_transaction: Option<HookConfig>push_to_checkout: Option<HookConfig>pre_auto_gc: Option<HookConfig>post_rewrite: Option<HookConfig>sendemail_validate: Option<HookConfig>fsmonitor_watchman: Option<HookConfig>p4_changelist: Option<HookConfig>p4_prepare_changelist: Option<HookConfig>p4_post_changelist: Option<HookConfig>p4_pre_submit: Option<HookConfig>post_index_change: Option<HookConfig>

Implementations

Source

impl Hooks

pub fn get(&self, name: &str) -> Option<&HookConfig>

Get a hook config by its git hook name (e.g. “pre-commit”).

pub fn set(&mut self, name: &str, cfg: HookConfig)

Set a hook config by its git hook name.

pub fn remove(&mut self, name: &str)

Remove a hook from the config by its git hook name.