pub struct LocalInclude {
pub path: String,
pub file_type: IncludeType,
pub ref_name: String,
}Expand description
An external file to import scripts from.
Fields
path: StringPath to the file, relative to the repository root.
file_type: IncludeTypeFile format.
ref_name: StringIdentifier used to reference this include in hook commands ($include: <ref>).