pub fn resolve_include_entry(
inc_ref: &IncludeRef,
includes: &[IncludeEntry],
) -> Result<Command>Expand description
Resolve a $include command entry by reading the referenced external file
and navigating the dot-notation path specified in run.
If args is set, it is appended to the resolved command string.
Supports local files, remote HTTP/HTTPS files, and files from remote Git repositories.